diff graal/com.oracle.graal.compiler.common/src/com/oracle/graal/compiler/common/type/IllegalStamp.java @ 22604:b00cc0475f31

Update jvmci import: Refactoring: Rename Kind to JavaKind.
author Roland Schatz <roland.schatz@oracle.com>
date Tue, 08 Sep 2015 19:57:39 +0200
parents 3285aa5a60f8
children 05183a084a08
line wrap: on
line diff
--- a/graal/com.oracle.graal.compiler.common/src/com/oracle/graal/compiler/common/type/IllegalStamp.java	Tue Sep 08 18:53:24 2015 +0200
+++ b/graal/com.oracle.graal.compiler.common/src/com/oracle/graal/compiler/common/type/IllegalStamp.java	Tue Sep 08 19:57:39 2015 +0200
@@ -28,9 +28,9 @@
 import com.oracle.graal.compiler.common.spi.*;
 
 /**
  * This stamp represents the type of the {@link Kind#Illegal} value in the second slot of
  * {@link Kind#Long} and {@link Kind#Double} values. It can only appear in framestates or virtual
  * objects.
  */
 public final class IllegalStamp extends Stamp {
 
@@ -38,8 +38,8 @@
     }
 
     @Override
-    public Kind getStackKind() {
-        return Kind.Illegal;
+    public JavaKind getStackKind() {
+        return JavaKind.Illegal;
     }
 
     @Override
@@ -59,7 +59,7 @@
 
     @Override
     public Stamp constant(Constant c, MetaAccessProvider meta) {
-        assert ((PrimitiveConstant) c).getKind() == Kind.Illegal;
+        assert ((PrimitiveConstant) c).getJavaKind() == JavaKind.Illegal;
         return this;
     }
@@ -28,9 +28,9 @@
 
 /**
- * This stamp represents the type of the {@link Kind#Illegal} value in the second slot of
- * {@link Kind#Long} and {@link Kind#Double} values. It can only appear in framestates or virtual
- * objects.
+ * This stamp represents the type of the {@link JavaKind#Illegal} value in the second slot of
+ * {@link JavaKind#Long} and {@link JavaKind#Double} values. It can only appear in framestates or
+ * virtual objects.
  */
 public final class IllegalStamp extends Stamp {